# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-26 05:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0044_sectionvideo_order'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='sectionvideo',
            options={'ordering': ['order']},
        ),
    ]
